Dr.Jit — A Just-In-Time-Compiler for Differentiable Rendering
=============================================================

.. image:: ../ext/drjit-core/resources/drjit-logo-dark.svg
  :width: 500
  :align: center
  :alt: Dr.Jit logo
  :class: only-light

.. image:: ../ext/drjit-core/resources/drjit-logo-light.svg
  :width: 500
  :align: center
  :alt: Dr.Jit logo
  :class: only-dark

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   intro
   firststeps-py
   firststeps-cpp
   reference
   release_notes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
